==> aws-cdk.aws-sagemaker-1.135.0.tar.gz: package/lib/sagemaker-canned-metrics.generated.d.ts <==
export declare class SageMakerMetrics {
    static invocationsSum(dimensions: {
        EndpointName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
        };
        statistic: string;
    };
    static invocation5XxErrorsSum(dimensions: {
        EndpointName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
        };
        statistic: string;
    };
    static invocation4XxErrorsSum(dimensions: {
        EndpointName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
        };
        statistic: string;
    };
    static invocationsPerInstanceSum(dimensions: {
        EndpointName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
        };
        statistic: string;
    };
    static modelLatencySum(dimensions: {
        EndpointName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
        };
        statistic: string;
    };
    static overheadLatencySum(dimensions: {
        EndpointName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-sagemaker-1.170.0.tar.gz: package/lib/sagemaker-canned-metrics.generated.d.ts <==
export declare class SageMakerMetrics {
    static invocationsSum(dimensions: {
        EndpointName: string;
        VariantName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
            VariantName: string;
        };
        statistic: string;
    };
    static invocation5XxErrorsSum(dimensions: {
        EndpointName: string;
        VariantName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
            VariantName: string;
        };
        statistic: string;
    };
    static invocation4XxErrorsSum(dimensions: {
        EndpointName: string;
        VariantName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
            VariantName: string;
        };
        statistic: string;
    };
    static invocationsPerInstanceSum(dimensions: {
        EndpointName: string;
        VariantName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
            VariantName: string;
        };
        statistic: string;
    };
    static modelLatencySum(dimensions: {
        EndpointName: string;
        VariantName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
            VariantName: string;
        };
        statistic: string;
    };
    static overheadLatencySum(dimensions: {
        EndpointName: string;
        VariantName: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            EndpointName: string;
            VariantName: string;
        };
        statistic: string;
    };
}
